gchecky.model.checkout_shopping_cart_t

Package gchecky :: Module model :: Class checkout_shopping_cart_t |
[hide private]
[frames] | no frames]

# Class checkout_shopping_cart_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    checkout_shopping_cart_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``checkout-shopping-cart``'`` The document's unique xml tag name.
| shopping_cart = `Node:PATH(shopping-cart):REQ:{ shopping_cart_t }`
| checkout_flow_support = `Node:PATH(checkout-flow-support/mercha`...``
| request_initial_auth_details = `gxml.Boolean('order-processing-`...``
| _fields = ``{``'``checkout_flow_support``'``:` Node:PATH(checkout-flow-su`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### checkout_flow_support Value:
      Node:PATH(checkout-flow-support/merchant-checkout-flow-support):REQ:{
      checkout_flow_support_t }

  ### request_initial_auth_details Value:
      gxml.Boolean('order-processing-support/request-initial-auth-details',
      required= False)

  ### _fields list of meta-Fields of this class. Value:
      {'checkout_flow_support': Node:PATH(checkout-flow-support/merchant-che
      ckout-flow-support):REQ:{ checkout_flow_support_t },
       'request_initial_auth_details': ??,
       'shopping_cart': Node:PATH(shopping-cart):REQ:{ shopping_cart_t }}